==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/midi/src/MIDI_ja_JP.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation type="unfinished">MIDIプラグイン設定</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation type="unfinished">更新</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation type="unfinished">デバイス名</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation type="unfinished">MIDIチャンネル</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation type="unfinished">モード</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation type="unfinished">Init Message</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation type="unfinished">出力</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation type="unfinished">入力</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation type="unfinished">無し</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation type="unfinished">このプラグインは、MIDIデバイスとの間でMIDI信号の送受信を行います。</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation type="unfinished">No output support available.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation type="unfinished">出力</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation type="unfinished">Open</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation type="unfinished">Not Open</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation type="unfinished">状態</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation type="unfinished">無効な出力</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation type="unfinished">No input support available.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation type="unfinished">入力</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation type="unfinished">無効な入力</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="196"/>
        <source>No error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="198"/>
        <source>An error occurred when reading from the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="200"/>
        <source>An error occurred when writing to the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="202"/>
        <source>A fatal error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="204"/>
        <source>Resource error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="206"/>
        <source>The file could not be opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="208"/>
        <source>The operation was aborted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="210"/>
        <source>A timeout occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="212"/>
        <source>An unspecified error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="214"/>
        <source>The file could not be removed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="216"/>
        <source>The file could not be renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="218"/>
        <source>The position in the file could not be changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="220"/>
        <source>The file could not be resized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="222"/>
        <source>The file could not be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="224"/>
        <source>The file could not be copied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="226"/>
        <source>An unknown error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qlcplus_4.12.6.orig.tar.xz: qlcplus-QLC-_4.12.6/plugins/midi/src/MIDI_ja_JP.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation type="unfinished">MIDIプラグイン設定</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation type="unfinished">更新</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation type="unfinished">デバイス名</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation type="unfinished">MIDIチャンネル</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation type="unfinished">モード</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation type="unfinished">Init Message</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation type="unfinished">出力</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation type="unfinished">入力</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation type="unfinished">無し</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation type="unfinished">このプラグインは、MIDIデバイスとの間でMIDI信号の送受信を行います。</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation type="unfinished">No output support available.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation type="unfinished">出力</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation type="unfinished">Open</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation type="unfinished">Not Open</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation type="unfinished">状態</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation type="unfinished">無効な出力</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation type="unfinished">No input support available.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation type="unfinished">入力</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation type="unfinished">無効な入力</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="112"/>
        <source>No error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="114"/>
        <source>An error occurred when reading from the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="116"/>
        <source>An error occurred when writing to the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="118"/>
        <source>A fatal error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="120"/>
        <source>Resource error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="122"/>
        <source>The file could not be opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="124"/>
        <source>The operation was aborted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="126"/>
        <source>A timeout occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="128"/>
        <source>An unspecified error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="130"/>
        <source>The file could not be removed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="132"/>
        <source>The file could not be renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="134"/>
        <source>The position in the file could not be changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="136"/>
        <source>The file could not be resized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="138"/>
        <source>The file could not be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="140"/>
        <source>The file could not be copied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="142"/>
        <source>An unknown error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
